<?php if (! $this->compact): ?>
<div class="controls separated">
    <?= $this->tabs ?>
    <?= $this->paginator ?>
    <div class="sort-controls-container">
        <?= $this->limiter ?>
    </div>
</div>
<?php endif ?>
<div class="content">
<?php if ($this->logData !== null): ?>
    <table class="action">
        <tbody>
        <?php foreach ($this->logData as $value): ?>
            <?php $datetime = new Datetime($value->datetime) ?>
            <tr class="state">
                <td style="width: 6em; text-align: center">
                    <?= $this->escape($datetime->format('d.m. H:i')) ?>
                    <br>
                    <?= $this->escape($value->type) ?>
                </td>
                <td style="width: 12em; text-align: center">
                    <?= $this->escape($value->identity) ?>
                </td>
                <td>
                    <?= nl2br($this->escape($value->message), false) ?>
                </td>
            </tr>
        <?php endforeach ?>
        </tbody>
    </table>
<?php endif ?>
</div>
