<?php if (! $this->compact): ?>
<div class="controls">
    <?= $this->tabs ?>
</div>
<?php endif ?>
<div class="content">
    <p><?= $this->escape($this->translate('No activity has been recorded yet.')) ?></p>
</div>
